# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.1.0

import enum
import typing
import uuid as _uuid

import winrt.system
from winrt import _winrt_windows_media_devices

__all__ = [
    "AdvancedPhotoMode",
    "AudioDeviceRole",
    "AutoFocusRange",
    "CameraOcclusionKind",
    "CameraStreamState",
    "CaptureSceneMode",
    "CaptureUse",
    "ColorTemperaturePreset",
    "DigitalWindowMode",
    "FocusMode",
    "FocusPreset",
    "HdrVideoMode",
    "InfraredTorchMode",
    "IsoSpeedPreset",
    "ManualFocusDistance",
    "MediaCaptureFocusState",
    "MediaCaptureOptimization",
    "MediaCapturePauseBehavior",
    "OpticalImageStabilizationMode",
    "RegionOfInterestType",
    "SendCommandStatus",
    "TelephonyKey",
    "VideoDeviceControllerGetDevicePropertyStatus",
    "VideoDeviceControllerSetDevicePropertyStatus",
    "VideoTemporalDenoisingMode",
    "ZoomTransitionMode",
    "AdvancedPhotoCaptureSettings",
    "AdvancedPhotoControl",
    "AudioDeviceController",
    "AudioDeviceModule",
    "AudioDeviceModuleNotificationEventArgs",
    "AudioDeviceModulesManager",
    "CallControl",
    "CameraOcclusionInfo",
    "CameraOcclusionState",
    "CameraOcclusionStateChangedEventArgs",
    "DefaultAudioCaptureDeviceChangedEventArgs",
    "DefaultAudioRenderDeviceChangedEventArgs",
    "DialRequestedEventArgs",
    "DigitalWindowBounds",
    "DigitalWindowCapability",
    "DigitalWindowControl",
    "ExposureCompensationControl",
    "ExposureControl",
    "ExposurePriorityVideoControl",
    "FlashControl",
    "FocusControl",
    "FocusSettings",
    "HdrVideoControl",
    "InfraredTorchControl",
    "IsoSpeedControl",
    "KeypadPressedEventArgs",
    "LowLagPhotoControl",
    "LowLagPhotoSequenceControl",
    "MediaDevice",
    "MediaDeviceControl",
    "MediaDeviceControlCapabilities",
    "ModuleCommandResult",
    "OpticalImageStabilizationControl",
    "PanelBasedOptimizationControl",
    "PhotoConfirmationControl",
    "RedialRequestedEventArgs",
    "RegionOfInterest",
    "RegionsOfInterestControl",
    "SceneModeControl",
    "TorchControl",
    "VideoDeviceController",
    "VideoDeviceControllerGetDevicePropertyResult",
    "VideoTemporalDenoisingControl",
    "WhiteBalanceControl",
    "ZoomControl",
    "ZoomSettings",
    "IDefaultAudioDeviceChangedEventArgs",
    "IMediaDeviceController",
    "CallControlEventHandler",
    "DialRequestedEventHandler",
    "KeypadPressedEventHandler",
    "RedialRequestedEventHandler",
]

class AdvancedPhotoMode(enum.IntEnum):
    AUTO = 0
    STANDARD = 1
    HDR = 2
    LOW_LIGHT = 3

class AudioDeviceRole(enum.IntEnum):
    DEFAULT = 0
    COMMUNICATIONS = 1

class AutoFocusRange(enum.IntEnum):
    FULL_RANGE = 0
    MACRO = 1
    NORMAL = 2

class CameraOcclusionKind(enum.IntEnum):
    LID = 0
    CAMERA_HARDWARE = 1

class CameraStreamState(enum.IntEnum):
    NOT_STREAMING = 0
    STREAMING = 1
    BLOCKED_FOR_PRIVACY = 2
    SHUTDOWN = 3

class CaptureSceneMode(enum.IntEnum):
    AUTO = 0
    MANUAL = 1
    MACRO = 2
    PORTRAIT = 3
    SPORT = 4
    SNOW = 5
    NIGHT = 6
    BEACH = 7
    SUNSET = 8
    CANDLELIGHT = 9
    LANDSCAPE = 10
    NIGHT_PORTRAIT = 11
    BACKLIT = 12

class CaptureUse(enum.IntEnum):
    NONE = 0
    PHOTO = 1
    VIDEO = 2

class ColorTemperaturePreset(enum.IntEnum):
    AUTO = 0
    MANUAL = 1
    CLOUDY = 2
    DAYLIGHT = 3
    FLASH = 4
    FLUORESCENT = 5
    TUNGSTEN = 6
    CANDLELIGHT = 7

class DigitalWindowMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class FocusMode(enum.IntEnum):
    AUTO = 0
    SINGLE = 1
    CONTINUOUS = 2
    MANUAL = 3

class FocusPreset(enum.IntEnum):
    AUTO = 0
    MANUAL = 1
    AUTO_MACRO = 2
    AUTO_NORMAL = 3
    AUTO_INFINITY = 4
    AUTO_HYPERFOCAL = 5

class HdrVideoMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class InfraredTorchMode(enum.IntEnum):
    OFF = 0
    ON = 1
    ALTERNATING_FRAME_ILLUMINATION = 2

class IsoSpeedPreset(enum.IntEnum):
    AUTO = 0
    ISO50 = 1
    ISO80 = 2
    ISO100 = 3
    ISO200 = 4
    ISO400 = 5
    ISO800 = 6
    ISO1600 = 7
    ISO3200 = 8
    ISO6400 = 9
    ISO12800 = 10
    ISO25600 = 11

class ManualFocusDistance(enum.IntEnum):
    INFINITY = 0
    HYPERFOCAL = 1
    NEAREST = 2

class MediaCaptureFocusState(enum.IntEnum):
    UNINITIALIZED = 0
    LOST = 1
    SEARCHING = 2
    FOCUSED = 3
    FAILED = 4

class MediaCaptureOptimization(enum.IntEnum):
    DEFAULT = 0
    QUALITY = 1
    LATENCY = 2
    POWER = 3
    LATENCY_THEN_QUALITY = 4
    LATENCY_THEN_POWER = 5
    POWER_AND_QUALITY = 6

class MediaCapturePauseBehavior(enum.IntEnum):
    RETAIN_HARDWARE_RESOURCES = 0
    RELEASE_HARDWARE_RESOURCES = 1

class OpticalImageStabilizationMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class RegionOfInterestType(enum.IntEnum):
    UNKNOWN = 0
    FACE = 1

class SendCommandStatus(enum.IntEnum):
    SUCCESS = 0
    DEVICE_NOT_AVAILABLE = 1

class TelephonyKey(enum.IntEnum):
    D0 = 0
    D1 = 1
    D2 = 2
    D3 = 3
    D4 = 4
    D5 = 5
    D6 = 6
    D7 = 7
    D8 = 8
    D9 = 9
    STAR = 10
    POUND = 11
    A = 12
    B = 13
    C = 14
    D = 15

class VideoDeviceControllerGetDevicePropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    BUFFER_TOO_SMALL = 2
    NOT_SUPPORTED = 3
    DEVICE_NOT_AVAILABLE = 4
    MAX_PROPERTY_VALUE_SIZE_TOO_SMALL = 5
    MAX_PROPERTY_VALUE_SIZE_REQUIRED = 6

class VideoDeviceControllerSetDevicePropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    NOT_SUPPORTED = 2
    INVALID_VALUE = 3
    DEVICE_NOT_AVAILABLE = 4
    NOT_IN_CONTROL = 5

class VideoTemporalDenoisingMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class ZoomTransitionMode(enum.IntEnum):
    AUTO = 0
    DIRECT = 1
    SMOOTH = 2

AdvancedPhotoCaptureSettings = _winrt_windows_media_devices.AdvancedPhotoCaptureSettings
AdvancedPhotoControl = _winrt_windows_media_devices.AdvancedPhotoControl
AudioDeviceController = _winrt_windows_media_devices.AudioDeviceController
AudioDeviceModule = _winrt_windows_media_devices.AudioDeviceModule
AudioDeviceModuleNotificationEventArgs = _winrt_windows_media_devices.AudioDeviceModuleNotificationEventArgs
AudioDeviceModulesManager = _winrt_windows_media_devices.AudioDeviceModulesManager
CallControl = _winrt_windows_media_devices.CallControl
CameraOcclusionInfo = _winrt_windows_media_devices.CameraOcclusionInfo
CameraOcclusionState = _winrt_windows_media_devices.CameraOcclusionState
CameraOcclusionStateChangedEventArgs = _winrt_windows_media_devices.CameraOcclusionStateChangedEventArgs
DefaultAudioCaptureDeviceChangedEventArgs = _winrt_windows_media_devices.DefaultAudioCaptureDeviceChangedEventArgs
DefaultAudioRenderDeviceChangedEventArgs = _winrt_windows_media_devices.DefaultAudioRenderDeviceChangedEventArgs
DialRequestedEventArgs = _winrt_windows_media_devices.DialRequestedEventArgs
DigitalWindowBounds = _winrt_windows_media_devices.DigitalWindowBounds
DigitalWindowCapability = _winrt_windows_media_devices.DigitalWindowCapability
DigitalWindowControl = _winrt_windows_media_devices.DigitalWindowControl
ExposureCompensationControl = _winrt_windows_media_devices.ExposureCompensationControl
ExposureControl = _winrt_windows_media_devices.ExposureControl
ExposurePriorityVideoControl = _winrt_windows_media_devices.ExposurePriorityVideoControl
FlashControl = _winrt_windows_media_devices.FlashControl
FocusControl = _winrt_windows_media_devices.FocusControl
FocusSettings = _winrt_windows_media_devices.FocusSettings
HdrVideoControl = _winrt_windows_media_devices.HdrVideoControl
InfraredTorchControl = _winrt_windows_media_devices.InfraredTorchControl
IsoSpeedControl = _winrt_windows_media_devices.IsoSpeedControl
KeypadPressedEventArgs = _winrt_windows_media_devices.KeypadPressedEventArgs
LowLagPhotoControl = _winrt_windows_media_devices.LowLagPhotoControl
LowLagPhotoSequenceControl = _winrt_windows_media_devices.LowLagPhotoSequenceControl
MediaDevice = _winrt_windows_media_devices.MediaDevice
MediaDeviceControl = _winrt_windows_media_devices.MediaDeviceControl
MediaDeviceControlCapabilities = _winrt_windows_media_devices.MediaDeviceControlCapabilities
ModuleCommandResult = _winrt_windows_media_devices.ModuleCommandResult
OpticalImageStabilizationControl = _winrt_windows_media_devices.OpticalImageStabilizationControl
PanelBasedOptimizationControl = _winrt_windows_media_devices.PanelBasedOptimizationControl
PhotoConfirmationControl = _winrt_windows_media_devices.PhotoConfirmationControl
RedialRequestedEventArgs = _winrt_windows_media_devices.RedialRequestedEventArgs
RegionOfInterest = _winrt_windows_media_devices.RegionOfInterest
RegionsOfInterestControl = _winrt_windows_media_devices.RegionsOfInterestControl
SceneModeControl = _winrt_windows_media_devices.SceneModeControl
TorchControl = _winrt_windows_media_devices.TorchControl
VideoDeviceController = _winrt_windows_media_devices.VideoDeviceController
VideoDeviceControllerGetDevicePropertyResult = _winrt_windows_media_devices.VideoDeviceControllerGetDevicePropertyResult
VideoTemporalDenoisingControl = _winrt_windows_media_devices.VideoTemporalDenoisingControl
WhiteBalanceControl = _winrt_windows_media_devices.WhiteBalanceControl
ZoomControl = _winrt_windows_media_devices.ZoomControl
ZoomSettings = _winrt_windows_media_devices.ZoomSettings
IDefaultAudioDeviceChangedEventArgs = _winrt_windows_media_devices.IDefaultAudioDeviceChangedEventArgs
IMediaDeviceController = _winrt_windows_media_devices.IMediaDeviceController
CallControlEventHandler = typing.Callable[[typing.Optional[CallControl]], None]
DialRequestedEventHandler = typing.Callable[[typing.Optional[CallControl], typing.Optional[DialRequestedEventArgs]], None]
KeypadPressedEventHandler = typing.Callable[[typing.Optional[CallControl], typing.Optional[KeypadPressedEventArgs]], None]
RedialRequestedEventHandler = typing.Callable[[typing.Optional[CallControl], typing.Optional[RedialRequestedEventArgs]], None]
